# UpdatePaymentRunRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_id** | **str** | The ID of the customer account associated with the payment run.  This field conflicts with each of the &#x60;batch&#x60;, &#x60;billCycleDay&#x60;, &#x60;currency&#x60;, &#x60;paymentGatewayId&#x60;, and &#x60;billingRunId&#x60; fields. If there are such conflicts, an error occurs and an error message is returned.  | [optional] 
**apply_credit_balance** | **bool** | **Note:** This field is only available if you have the Credit Balance feature enabled and the Invoice Settlement feature disabled.  Whether to apply credit balances in the payment run. This field is only available when you have Invoice Settlement feature disabled.  | [optional] 
**auto_apply_credit_memo** | **bool** | **Note:** This field is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  Whether to automatically apply a posted credit memo to one or more receivables in the payment run.  | [optional] 
**auto_apply_unapplied_payment** | **bool** | **Note:** This field is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  Whether to automatically apply unapplied payments to  one or more receivables in the payment run.  | [optional] 
**batch** | **str** | The alias name given to a batch. The batch name is a string of 50 characters or less.  This field conflicts with the &#x60;accountId&#x60; field. If they are both specified in the request body, an error occurs and an error message is returned.   | [optional] 
**bill_cycle_day** | **str** | The billing cycle day (BCD), the day of the month when a bill run generates invoices for the account. The value must be equal to or less then 31, and 31 is mean the EOM.  This field conflicts with the &#x60;accountId&#x60; field. If they are both specified in the request body, an error occurs and an error message is returned.  | [optional] 
**billing_run_id** | **str** | The ID of a bill run.  This field conflicts with the &#x60;accountId&#x60; field. If they are both specified in the request body, an error occurs and an error message is returned.  | [optional] 
**collect_payment** | **bool** | Whether to process electronic payments during the execution of payment runs.   If the Payment user permission \&quot;Process Electronic Payment\&quot; is disabled, this field will be ignored.  | [optional] 
**consolidated_payment** | **bool** | **Note:** The **Process Electronic Payment** permission also needs to be allowed for a Manage Payment Runs role to work. See [Payments Roles](https://knowledgecenter.zuora.com/CF_Users_and_Administrators/A_Administrator_Settings/User_Roles/e_Payments_Roles) for more information.   Whether to process a single payment for all receivables that are due on an account.  | [optional] 
**currency** | **str** | A currency defined in the web-based UI administrative settings.  This field conflicts with the &#x60;accountId&#x60; field. If they are both specified in the request body, an error occurs and an error message is returned.  | [optional] 
**payment_gateway_id** | **str** | The ID of the gateway instance that processes the payment.  This field conflicts with the &#x60;accountId&#x60; field. If they are both specified in the request body, an error occurs and an error message is returned.  | [optional] 
**process_payment_with_closed_pm** | **bool** | **Note:** The **Process Electronic Payment** permission also needs to be allowed for a Manage Payment Runs role to work. See [Payments Roles](https://knowledgecenter.zuora.com/CF_Users_and_Administrators/A_Administrator_Settings/User_Roles/e_Payments_Roles) for more information.   Whether to process payments even if the default payment method is closed.  | [optional] 
**run_date** | **datetime** | The date and time when the scheduled payment run is to be executed, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. The backend will ignore mintues and seconds in the field value. For example, if you specify &#x60;2017-03-01 11:30:37&#x60; for this value, this payment run will be run at 2017-03-01 11:00:00.  | [optional] 
**target_date** | **date** | The target date used to determine which receivables to be paid in the payment run. The payments are collected for all receivables with the due date no later than the target date.  | [optional] 

## Example

```python
from zuora_sdk.models.update_payment_run_request import UpdatePaymentRunRequest

# TODO update the JSON string below
json = "{}"
# create an instance of UpdatePaymentRunRequest from a JSON string
update_payment_run_request_instance = UpdatePaymentRunRequest.from_json(json)
# print the JSON string representation of the object
print(UpdatePaymentRunRequest.to_json())

# convert the object into a dict
update_payment_run_request_dict = update_payment_run_request_instance.to_dict()
# create an instance of UpdatePaymentRunRequest from a dict
update_payment_run_request_from_dict = UpdatePaymentRunRequest.from_dict(update_payment_run_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


